@@ -16,9 +16,13 @@
 
 #pragma once
 
+#include <functional>
+#include <map>
+#include <string>
+
 #include <folly/Chrono.h>
+#include <folly/Range.h>
 #include <folly/Synchronized.h>
-#include <folly/experimental/StringKeyedMap.h>
 #include <folly/synchronization/RelaxedAtomic.h>
 
 namespace facebook {
@@ -102,8 +106,9 @@ class CallbackValuesMap {
   // match, cache is valid.
   template <typename Mapped>
   struct MapWithKeyCache {
-    folly::StringKeyedMap<Mapped> map;
-    mutable folly::StringKeyedMap<std::vector<std::string>> regexCache;
+    std::map<std::string, Mapped, std::less<>> map;
+    mutable std::map<std::string, std::vector<std::string>, std::less<>>
+        regexCache;
     mutable folly::relaxed_atomic_uint64_t mapEpoch{0};
     mutable folly::relaxed_atomic_uint64_t cacheEpoch{0};
     mutable folly::chrono::coarse_system_clock::time_point cacheClearTime{
