@@ -112,11 +112,15 @@ struct QuantileConsts {
       {.01, .1, .75, .9, .95, .99}};
   static constexpr const std::array<double, 6> kP50_P75_P90_P95_P99_P999{
       {.5, .75, .9, .95, .99, .999}};
+  static constexpr const std::array<double, 6> kP50_kP95_kP99_P999_P9999_P100{
+      {.5, .95, .99, .999, .9999, 1}};
   static constexpr const std::array<double, 5> kP50_P70_P90_P95_P99{
       {.5, .7, .9, .95, .99}};
   static constexpr const std::array<double, 4> kP50_P95_P99_P100{
       {.5, .95, .99, 1}};
   static constexpr const std::array<double, 2> kP0_P100{{.0, 1}};
+  static constexpr const std::array<double, 4> kP25_p50_p75_p95{
+      {.25, 0.5, 0.75, 0.95}};
 };
 
 struct SlidingWindowPeriodConsts {
