@@ -65,8 +65,9 @@ ExportedHistogramMap::HistogramPtr ExportedHistogramMap::getOrCreateUnlocked(
   {
     // The returned iterator may be invalidated by a concurrent insert, so it
     // must be dereferenced before releasing the lock guard.
-    auto lockedHistMap = histMap_.lock();
-    auto item = lockedHistMap->insert({name, std::move(value)});
+    HistMap::value_type toInsert(name, std::move(value));
+    auto lockedHistMap = histMap_.wlock();
+    auto item = lockedHistMap->insert(std::move(toInsert));
     inserted = item.second;
     hist = item.first->second;
     CHECK(hist);
@@ -112,7 +113,7 @@ bool ExportedHistogramMap::addHistogram(
 
   // Acquire the lock while attempting the insert.
   {
-    auto lockedHistMap = histMap_.lock();
+    auto lockedHistMap = histMap_.wlock();
 
     // Call emplace() with a null HistogramPtr first.  Creating a new histogram
     // object is somewhat expensive, so wait to create it until we know we'll
@@ -134,7 +135,7 @@ bool ExportedHistogramMap::addHistogram(
     };
 
     newHistogram = std::make_shared<SyncHistogram>(
-        folly::in_place, bucketWidth, min, max, **defaultStat_.rlock());
+        std::in_place, bucketWidth, min, max, **defaultStat_.rlock());
     ret.first->second = newHistogram;
 
     // End of scope:
@@ -210,7 +211,7 @@ void ExportedHistogramMap::unexportStat(StringPiece name, ExportType type) {
 }
 
 void ExportedHistogramMap::clearAllHistograms() {
-  auto lockedHistMap = histMap_.lock();
+  auto lockedHistMap = histMap_.wlock();
   for (auto& histPtrKvp : *lockedHistMap) {
     histPtrKvp.second->lock()->clear();
   }
