@@ -473,9 +473,8 @@ class FormattedKeyHolder {
   // round down floating-point keys or get a runtime-error with nullptrs.
   template <typename T>
   static constexpr bool IsValidSubkey =
-      (std::is_convertible_v<T, folly::StringPiece> ||
-       std::is_integral_v<T>)&&!std::is_same_v<T, std::nullptr_t> &&
-      !std::is_same_v<T, bool>;
+      (std::is_convertible_v<T, folly::StringPiece> || std::is_integral_v<T>) &&
+      !std::is_same_v<T, std::nullptr_t> && !std::is_same_v<T, bool>;
 
   // Hash function
   struct SubkeyHash //
@@ -1159,8 +1158,7 @@ class HistogramWrapper {
 
   void add(int64_t value = 1) {
     ensureApplySpec();
-    (*ThreadCachedServiceData::getStatsThreadLocal())
-        .addHistogramValue(key_, value);
+    tcHistogram()->addValue(value);
   }
 
  protected:
@@ -1172,9 +1170,23 @@ class HistogramWrapper {
     folly::call_once(once_, &HistogramWrapper::doApplySpecLocked, this);
   }
 
+  inline ThreadCachedServiceData::TLHistogram* tcHistogram() {
+    ThreadCachedServiceData::TLHistogram* cached = tlHistogram_->get();
+    if (cached) {
+      return cached;
+    }
+
+    auto histogram =
+        ThreadCachedServiceData::getStatsThreadLocal()->getHistogramSafe(key_);
+    *tlHistogram_ = histogram;
+    return histogram.get();
+  }
+
   folly::once_flag once_;
   std::string key_;
   internal::HistogramSpec spec_;
+  folly::ThreadLocal<std::shared_ptr<ThreadCachedServiceData::TLHistogram>>
+      tlHistogram_;
 };
 
 class MinuteOnlyHistogram : public HistogramWrapper {
